package name.nathanmcrae;

import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.fxml.FXML;
import javafx.scene.control.ListView;
import javafx.scene.control.TextInputDialog;
import javafx.event.ActionEvent;
import javafx.event.Event;
import javafx.scene.Node;
import javafx.stage.Stage;

import java.util.Optional;

public class NumbersStationSelectionController {

    @FXML
    private ListView<String> stationListView;

    private ObservableList<String> stationList;

    public NumbersStationSelectionController() {
        // Initialize the list with an empty list
        stationList = FXCollections.observableArrayList();
    }

    @FXML
    private void initialize() {
    }

    public void setSettings(NumbersStationSettings settings) {
        // Populate the list with stations from settings
        for (StationSettings station : settings.getStations()) {
            System.out.println("Adding station: " + station.getName());
            stationList.add(station.getName());
            stationListView.setItems(stationList);
        }
    }

    @FXML
    private void handleAddButtonPress(ActionEvent event) {
        // Create a TextInputDialog
        TextInputDialog dialog = new TextInputDialog();
        dialog.setTitle("New Station");
        dialog.setHeaderText("Add a New Station");
        dialog.setContentText("Please enter the station name:");

        // Show the dialog and capture the result
        Optional<String> result = dialog.showAndWait();
        result.ifPresent(stationName -> {
            // Add the new station to the list
            stationList.add(stationName);
        });
    }

    @FXML
    private void handleRemoveButtonPress(ActionEvent event) {
        // Remove the selected item from the list
        int selectedIndex = stationListView.getSelectionModel().getSelectedIndex();
        if (selectedIndex >= 0) {
            stationList.remove(selectedIndex);
        }
    }

    @FXML
    private void handleSelectButtonPress(Event e) {
        Node node = (Node) e.getSource();
        Stage stage = (Stage) node.getScene().getWindow();
        String selectedStation = stationListView.getSelectionModel().getSelectedItem();

        if (selectedStation != null) {
            stage.setUserData(selectedStation);
            System.out.println("Selected Station: " + selectedStation);
        }
        stage.close();
    }
}
